import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ActivatedRoute } from '@angular/router';
import { FaIconComponent } from '@fortawesome/angular-fontawesome';
import { 
  faArrowLeft,
  faBookmark,
  faShareNodes,
  faPaperPlane
} from '@fortawesome/free-solid-svg-icons';

// 定义职位详情接口
interface JobDetail {
  id: string;
  title: string;
  salary: string;
  companyLogo: string;
  companyName: string;
  location: string;
  experience: string;
  education: string;
  tags: string[];
  match: number;
  description: string;
  benefits: string[];
}

@Component({
  selector: 'app-page-job-detail',
  standalone: true,
  imports: [CommonModule, FaIconComponent],
  templateUrl: './page-job-detail.html',
  styleUrls: ['./page-job-detail.scss']
})
export class PageJobDetail {
  icons = {
    arrowLeft: faArrowLeft,
    bookmark: faBookmark,
    share: faShareNodes,
    apply: faPaperPlane
  };

  job!: JobDetail;
  
  constructor(private route: ActivatedRoute) {
    // 使用非空断言操作符(!)告诉TypeScript我们知道这个值不会是null
    const jobId = this.route.snapshot.paramMap.get('id')!;
    this.loadJobDetail(jobId);
  }

  loadJobDetail(jobId: string) {
    // 定义更完整的模拟数据类型
    const mockJobs: Record<string, JobDetail> = {
      '1': {
        id: '1',
        title: '前端开发工程师',
        salary: '25-40K·15薪',
        companyLogo: 'TX',
        companyName: '腾讯科技',
        location: '深圳',
        experience: '3-5年',
        education: '本科及以上',
        tags: ['Vue.js', 'React', 'TypeScript'],
        match: 87,
        description: '岗位职责：\n1. 负责公司前端项目开发与维护\n2. 参与产品需求讨论和技术方案设计\n3. 优化前端性能，提升用户体验\n\n任职要求：\n1. 精通HTML/CSS/JavaScript\n2. 熟练掌握Vue.js/React框架\n3. 有大型项目开发经验者优先',
        benefits: ['五险一金', '年度体检', '带薪年假', '弹性工作制']
      },
      '2': {
        id: '2',
        title: 'Java高级工程师',
        salary: '30-50K·16薪',
        companyLogo: 'AL',
        companyName: '阿里巴巴',
        location: '杭州',
        experience: '5-8年',
        education: '本科及以上',
        tags: ['Spring Cloud', '分布式', 'MySQL'],
        match: 76,
        description: '岗位职责：\n1. 负责核心系统架构设计与开发\n2. 解决高并发场景下的技术难题\n3. 参与技术方案评审\n\n任职要求：\n1. 精通Java及常用框架\n2. 熟悉分布式系统设计\n3. 有性能优化经验',
        benefits: ['六险一金', '股票期权', '免费三餐', '年度旅游']
      },
      '3': {
        id: '3',
        title: '产品经理',
        salary: '20-35K·14薪',
        companyLogo: 'BD',
        companyName: '百度',
        location: '北京',
        experience: '3-5年',
        education: '本科及以上',
        tags: ['Axure', '用户研究', 'PRD'],
        match: 92,
        description: '岗位职责：\n1. 负责产品规划与设计\n2. 进行市场调研和竞品分析\n3. 协调研发团队推进产品落地\n\n任职要求：\n1. 熟悉产品设计流程\n2. 优秀的沟通协调能力\n3. 有成功产品案例',
        benefits: ['五险一金', '弹性工作', '学习基金', '健身房']
      }
    };
    
    // 使用类型断言确保jobId是mockJobs的合法键
    this.job = mockJobs[jobId as keyof typeof mockJobs] || mockJobs['1'];
  }

  goBack() {
    window.history.back();
  }

  applyJob() {
    alert(`已申请 ${this.job.title} 职位`);
  }
}