import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Router } from '@angular/router';
import { FaIconComponent } from '@fortawesome/angular-fontawesome';
import { 
  faBook, faSearch, faChevronRight, 
  faMicrophone, faPlay, faCheck
} from '@fortawesome/free-solid-svg-icons';

@Component({
  selector: 'app-page-question-bank',
  standalone: true,
  imports: [CommonModule, FormsModule, FaIconComponent],
  templateUrl: './page-question-bank.html',
  styleUrls: ['./page-question-bank.scss']
})
export class PageQuestionBank {
  icons = {
    book: faBook,
    search: faSearch,
    arrowRight: faChevronRight,
    mic: faMicrophone,
    play: faPlay,
    check: faCheck
  };

  categories = [
    {
      id: 1,
      name: '技术类',
      questions: [
        "请解释一下闭包的概念及其应用场景",
        "谈谈你对React/Vue框架的理解",
        "如何优化前端性能",
        "解释一下HTTP和HTTPS的区别"
      ]
    },
    {
      id: 2,
      name: '行为类',
      questions: [
        "请描述一个你遇到的技术难题及解决方法",
        "你如何与意见不合的同事合作",
        "描述一个你领导项目的经历"
      ]
    },
    {
      id: 3,
      name: '情景类',
      questions: [
        "如果项目截止日期提前，你会如何处理",
        "当客户需求频繁变更时你会怎么做"
      ]
    }
  ];

  selectedCategory: any = null;
  searchTerm = '';
  currentQuestion = '';
  userAnswer = '';
  isRecording = false;
  showAnalysis = false;
  analysisResult: any = null;

  constructor(private router: Router) {}

  selectCategory(category: any) {
    this.selectedCategory = category;
    this.showAnalysis = false;
  }

  backToCategories() {
    this.selectedCategory = null;
    this.showAnalysis = false;
  }

  startRecording() {
    this.isRecording = true;
    // 实际项目中这里会调用语音识别API
    setTimeout(() => {
      this.userAnswer = "这是我的模拟回答...";
      this.isRecording = false;
    }, 2000);
  }

  speakQuestion() {
    // 使用浏览器语音合成API朗读问题
    if ('speechSynthesis' in window) {
      const utterance = new SpeechSynthesisUtterance(this.currentQuestion);
      window.speechSynthesis.speak(utterance);
    } else {
      console.warn('您的浏览器不支持语音合成功能');
    }
  }

  submitAnswer() {
    // 模拟分析过程
    this.analysisResult = {
      question: this.currentQuestion,
      answer: this.userAnswer,
      scores: {
        relevance: Math.floor(Math.random() * 30) + 70,
        clarity: Math.floor(Math.random() * 30) + 70,
        depth: Math.floor(Math.random() * 30) + 70
      },
      feedback: "您的回答结构清晰，但可以增加更多具体案例来增强说服力。",
      suggestions: [
        "尝试使用STAR法则(Situation, Task, Action, Result)来组织回答",
        "加入具体数据或成果来量化您的工作",
        "保持回答在1-2分钟内"
      ]
    };
    this.showAnalysis = true;
  }

  get filteredCategories() {
    if (!this.searchTerm) return this.categories;
    
    return this.categories.map(category => ({
      ...category,
      questions: category.questions.filter(q => 
        q.toLowerCase().includes(this.searchTerm.toLowerCase()))
    })).filter(category => category.questions.length > 0);
  }
}